# IGMOV

[![PyPI version](https://badge.fury.io/py/igmov.svg)](https://pypi.org/project/igmov/)
![Upload Python Package](https://github.com/ngupuk/igmov/workflows/Upload%20Python%20Package/badge.svg)

Video Editing Program for Podcast Preview

- [Documentation](https://github.com/ngupuk/igmov/wiki) : language Indonesian